mathjax: A JavaScript library for displaying mathematical formulas
==================================================================

Description
-----------

MathJax is a JavaScript library for displaying mathematical formulas.

MathJax is used in the Sage documentation built by Sphinx.

License
-------

Apache License, version 2.0

Upstream Contact
----------------

Home page: https://www.mathjax.org/
